
/* the type of radio, there's one of these for each plugin */
enum RSRadioType
{
    RSTypeUnknown = -1,
    RSTypeAirPort,
    RSTypeBluetooth,
    RSTypeUSB80211b,
};

enum RSRadioSecure
{
    RSSecureUnknown = -1,
    RSSecureOpen,
    RSSecureClosed,
    RSSecureWEP,
    RSSecureLEAP,
    RSSecure8021x,
    RSSecureWPA,
    RSSecureBluetoothMixed,
    RSSecureBluetoothEncrypted
};

/* 

Channels in the ISM band range from: 2400 MHz – 2483.5 MHz

North America, Austraila and New Zeland use channnels 1 through 11

Eurpoe ETSI uses channels 1 through 13

Japan uses channels 1 through 13 

Mexico is included in the North America  regulatory domain; however, 
only channels 9 through 11 can be used in  Mexico. 

Israel is included in the ETSI  regulatory domain; however,
only channels 3 through 9 can be used in  Israel. 

France is included in the ETSI  regulatory domain; however,
only channels 10 through 13 can be used in  France. 

*/
enum RSRadioISMFrequencies // in Mhz
{
    ISMChannelOffset = 5, // channels are offset 5mhz from each other
    ISMChannelWidth = 30, // channels are 30mhz wide
    ISMChannel0  = 2407, // not a real channel, used for conversion function
    ISMChannel1  = 2412, // IMSChannel0 + IMSChannelOffset ...
    ISMChannel2  = 2417,
    ISMChannel3  = 2422,
    ISMChannel4  = 2427,
    ISMChannel5  = 2432,
    ISMChannel6  = 2437,
    ISMChannel7  = 2442,
    ISMChannel8  = 2447,
    ISMChannel9  = 2452,
    ISMChannel10 = 2457,
    ISMChannel11 = 2462,
    ISMChannel12 = 2467,
    ISMChannel13 = 2472,
    ISMChannel14 = 2477
};


@class RSSample;

@interface RSRadio : NSObject 
{
    NSString*               radio_mac;
    NSString*               radio_name;
    enum RSRadioType        radio_type;
    enum RSRadioSecure      radio_secure;
    NSString*               radio_info;
    NSImage*                radio_icon;
    NSImage*                radio_small_icon;
    NSMutableDictionary*    radio_props;
    NSMutableArray*         radio_samples;
    RSSample*               best_sample;
}

+ (float) frequencyOfChannel:(int) channel;
+ (int) channelOfFrequency:(float) freq;

+ (float) signalDBIAsPercentage:(int) signal;

+ (NSString*) radioTypeString:(enum RSRadioType) type;

- (RSRadio*) initWithMac:(NSString*) mac 
                    name:(NSString*) name 
                    type:(enum RSRadioType) type 
                    secure:(enum RSRadioSecure) secure;

- (RSRadio*) initWithMac:(NSString*) mac 
                    name:(NSString*) name 
                    type:(enum RSRadioType) type 
                    secure:(enum RSRadioSecure) secure
                   props:(NSDictionary*) props;

/* these are the standard mutators for the principal attributes */

- (NSString*) mac;

- (NSString*) macVendor;

- (void) setMac:(NSString*)mac;

- (NSString*) name;
- (void) setName:(NSString*)mac;

- (enum RSRadioType) type;
- (void) setType:(enum RSRadioType)radio;

- (enum RSRadioSecure) secure;
- (void) setSecure:(enum RSRadioSecure) secure;

- (NSString*) info;
- (void) setInfo:(NSString*) info;

- (NSImage*) icon;
- (void) setIcon:(NSImage*) image;

- (NSImage*) smallIcon;
- (void) setSmallIcon:(NSImage*) image;

/* string conversion conveniences  */

- (NSString*) typeAsString;
- (NSString*) secureAsString;

/*  */

- (BOOL) isPublic;

/* methods to manage the properties of the radio */

- (NSEnumerator*) propertyNames;
- (id) property:(NSString*) name;
- (void) setProperty:(NSObject*) prop forName:(NSString*) name;
- (void) removeProperty:(NSString*) name;
- (void) addPropertiesFromDictionary:(NSDictionary*) props;

/* methods to examine the samples taken of the radios signal */

- (void) addSample: (RSSample*) sample;
- (NSArray*) samples;
- (int) countSamples;
- (RSSample*) lastSample;
- (RSSample*) bestSample;

/* conveniance for addSample */

- (RSSample*) sampleSignalDBI:(int) signal
                     noiseDBI:(int) noise
                   ISMChannel:(int) channel;

- (RSSample*) sampleSignal:(float) signal
                     noise:(float) noise
                      freq:(float) freq;

/* methods to manage the population of samples by forgetting old ones */

- (int) forgetSamplesBefore:(NSDate*) thirty;

- (int) forgetSamplesBefore:(NSDate*) thirty saveLast:(BOOL) save;

/* get the radio's info in a convenient dictionary */
- (NSDictionary*) radioInfo;

- (NSString*) debugDescription;

@end

/*  Copyright (c) 2005, Alf Watt (alf@istumbler.net). All rights reserved.
Redistribution and use permitted under BSD-Style license.   */
